diff --git a/qtbase/src/platformsupport/input/xkbcommon/qxkbcommon.cpp b/qtbase/src/platformsupport/input/xkbcommon/qxkbcommon.cpp
index 9aa8f10..d2a16ae 100644
--- a/qtbase/src/platformsupport/input/xkbcommon/qxkbcommon.cpp
+++ b/qtbase/src/platformsupport/input/xkbcommon/qxkbcommon.cpp
@@ -273,10 +273,10 @@ static constexpr const auto KeyTbl = qMakeArray(
         Xkb2Qt<XKB_KEY_dead_small_schwa,        Qt::Key_Dead_Small_Schwa>,
         Xkb2Qt<XKB_KEY_dead_capital_schwa,      Qt::Key_Dead_Capital_Schwa>,
         Xkb2Qt<XKB_KEY_dead_greek,              Qt::Key_Dead_Greek>,
-        Xkb2Qt<XKB_KEY_dead_lowline,            Qt::Key_Dead_Lowline>,
-        Xkb2Qt<XKB_KEY_dead_aboveverticalline,  Qt::Key_Dead_Aboveverticalline>,
-        Xkb2Qt<XKB_KEY_dead_belowverticalline,  Qt::Key_Dead_Belowverticalline>,
-        Xkb2Qt<XKB_KEY_dead_longsolidusoverlay, Qt::Key_Dead_Longsolidusoverlay>,
+        
+        
+        
+        
 
         // Special keys from X.org - This include multimedia keys,
         // wireless/bluetooth/uwb keys, special launcher keys, etc.
diff --git a/qtlocation/src/3rdparty/mapbox-gl-native/include/mbgl/util/geometry.hpp b/qtlocation/src/3rdparty/mapbox-gl-native/include/mbgl/util/geometry.hpp
index a28c59a..1404d82 100644
--- a/qtlocation/src/3rdparty/mapbox-gl-native/include/mbgl/util/geometry.hpp
+++ b/qtlocation/src/3rdparty/mapbox-gl-native/include/mbgl/util/geometry.hpp
@@ -1,4 +1,5 @@
 #pragma once
+#include <cstdint>
 
 #include <mapbox/geometry/geometry.hpp>
 #include <mapbox/geometry/point_arithmetic.hpp>
diff --git a/qtlocation/src/3rdparty/mapbox-gl-native/include/mbgl/util/string.hpp b/qtlocation/src/3rdparty/mapbox-gl-native/include/mbgl/util/string.hpp
index 13498cc..4ae31c1 100644
--- a/qtlocation/src/3rdparty/mapbox-gl-native/include/mbgl/util/string.hpp
+++ b/qtlocation/src/3rdparty/mapbox-gl-native/include/mbgl/util/string.hpp
@@ -1,4 +1,5 @@
 #pragma once
+#include <cstdint>
 
 #include <sstream>
 #include <string>
diff --git a/qtlocation/src/3rdparty/mapbox-gl-native/src/mbgl/gl/stencil_mode.hpp b/qtlocation/src/3rdparty/mapbox-gl-native/src/mbgl/gl/stencil_mode.hpp
index bc959c9..f958ba5 100644
--- a/qtlocation/src/3rdparty/mapbox-gl-native/src/mbgl/gl/stencil_mode.hpp
+++ b/qtlocation/src/3rdparty/mapbox-gl-native/src/mbgl/gl/stencil_mode.hpp
@@ -1,4 +1,5 @@
 #pragma once
+#include <cstdint>
 
 #include <mbgl/util/variant.hpp>
 
diff --git a/qtwebengine/src/3rdparty/chromium/content/public/browser/browsing_data_remover_delegate.h b/qtwebengine/src/3rdparty/chromium/content/public/browser/browsing_data_remover_delegate.h
index 3896bc6..68076c2 100644
--- a/qtwebengine/src/3rdparty/chromium/content/public/browser/browsing_data_remover_delegate.h
+++ b/qtwebengine/src/3rdparty/chromium/content/public/browser/browsing_data_remover_delegate.h
@@ -4,6 +4,7 @@
 
 #ifndef CONTENT_PUBLIC_BROWSER_BROWSING_DATA_REMOVER_DELEGATE_H_
 #define CONTENT_PUBLIC_BROWSER_BROWSING_DATA_REMOVER_DELEGATE_H_
+#include <cstdint>
 
 #include <string>
 #include <vector>
diff --git a/qtwebengine/src/3rdparty/chromium/device/base/synchronization/one_writer_seqlock.cc b/qtwebengine/src/3rdparty/chromium/device/base/synchronization/one_writer_seqlock.cc
index 213b630..9332e37 100644
--- a/qtwebengine/src/3rdparty/chromium/device/base/synchronization/one_writer_seqlock.cc
+++ b/qtwebengine/src/3rdparty/chromium/device/base/synchronization/one_writer_seqlock.cc
@@ -3,6 +3,7 @@
 // found in the LICENSE file.
 
 #include "device/base/synchronization/one_writer_seqlock.h"
+#include <cstdint>
 
 namespace device {
 
diff --git a/qtwebengine/src/3rdparty/chromium/device/bluetooth/public/cpp/bluetooth_uuid.h b/qtwebengine/src/3rdparty/chromium/device/bluetooth/public/cpp/bluetooth_uuid.h
index 0c27ae7..ebe760b 100644
--- a/qtwebengine/src/3rdparty/chromium/device/bluetooth/public/cpp/bluetooth_uuid.h
+++ b/qtwebengine/src/3rdparty/chromium/device/bluetooth/public/cpp/bluetooth_uuid.h
@@ -4,6 +4,7 @@
 
 #ifndef DEVICE_BLUETOOTH_PUBLIC_CPP_BLUETOOTH_UUID_H_
 #define DEVICE_BLUETOOTH_PUBLIC_CPP_BLUETOOTH_UUID_H_
+#include <cstdint>
 
 #include <string>
 #include <vector>
diff --git a/qtwebengine/src/3rdparty/chromium/extensions/browser/api/audio/audio_device_id_calculator.h b/qtwebengine/src/3rdparty/chromium/extensions/browser/api/audio/audio_device_id_calculator.h
index 9d28581..1bec30e 100644
--- a/qtwebengine/src/3rdparty/chromium/extensions/browser/api/audio/audio_device_id_calculator.h
+++ b/qtwebengine/src/3rdparty/chromium/extensions/browser/api/audio/audio_device_id_calculator.h
@@ -4,6 +4,7 @@
 
 #ifndef EXTENSIONS_BROWSER_API_AUDIO_AUDIO_DEVICE_ID_CALCULATOR_H_
 #define EXTENSIONS_BROWSER_API_AUDIO_AUDIO_DEVICE_ID_CALCULATOR_H_
+#include <cstdint>
 
 #include <map>
 #include <string>
diff --git a/qtwebengine/src/3rdparty/chromium/gpu/command_buffer/common/webgpu_cmd_enums.h b/qtwebengine/src/3rdparty/chromium/gpu/command_buffer/common/webgpu_cmd_enums.h
index 83615b3..f8b89ee 100644
--- a/qtwebengine/src/3rdparty/chromium/gpu/command_buffer/common/webgpu_cmd_enums.h
+++ b/qtwebengine/src/3rdparty/chromium/gpu/command_buffer/common/webgpu_cmd_enums.h
@@ -4,6 +4,7 @@
 
 #ifndef GPU_COMMAND_BUFFER_COMMON_WEBGPU_CMD_ENUMS_H_
 #define GPU_COMMAND_BUFFER_COMMON_WEBGPU_CMD_ENUMS_H_
+#include <cstdint>
 
 namespace gpu {
 namespace webgpu {
diff --git a/qtwebengine/src/3rdparty/chromium/gpu/config/device_perf_info.h b/qtwebengine/src/3rdparty/chromium/gpu/config/device_perf_info.h
index e33874b..71756ad 100644
--- a/qtwebengine/src/3rdparty/chromium/gpu/config/device_perf_info.h
+++ b/qtwebengine/src/3rdparty/chromium/gpu/config/device_perf_info.h
@@ -4,6 +4,7 @@
 
 #ifndef GPU_CONFIG_DEVICE_PERF_INFO_H_
 #define GPU_CONFIG_DEVICE_PERF_INFO_H_
+#include <cstdint>
 
 #include <string>
 #include <vector>
diff --git a/qtwebengine/src/3rdparty/chromium/gpu/config/gpu_feature_info.h b/qtwebengine/src/3rdparty/chromium/gpu/config/gpu_feature_info.h
index 027f1a5..918fb8a 100644
--- a/qtwebengine/src/3rdparty/chromium/gpu/config/gpu_feature_info.h
+++ b/qtwebengine/src/3rdparty/chromium/gpu/config/gpu_feature_info.h
@@ -4,6 +4,7 @@
 
 #ifndef GPU_CONFIG_GPU_FEATURE_INFO_H_
 #define GPU_CONFIG_GPU_FEATURE_INFO_H_
+#include <cstdint>
 
 #include <string>
 #include <vector>
diff --git a/qtwebengine/src/3rdparty/chromium/gpu/config/gpu_preferences.h b/qtwebengine/src/3rdparty/chromium/gpu/config/gpu_preferences.h
index 6b85871..e81eedb 100644
--- a/qtwebengine/src/3rdparty/chromium/gpu/config/gpu_preferences.h
+++ b/qtwebengine/src/3rdparty/chromium/gpu/config/gpu_preferences.h
@@ -4,6 +4,7 @@
 
 #ifndef GPU_CONFIG_GPU_PREFERENCES_H_
 #define GPU_CONFIG_GPU_PREFERENCES_H_
+#include <cstdint>
 
 #include <stddef.h>
 #include <string>
diff --git a/qtwebengine/src/3rdparty/chromium/media/capture/video/linux/v4l2_capture_delegate.cc b/qtwebengine/src/3rdparty/chromium/media/capture/video/linux/v4l2_capture_delegate.cc
index fc2ed86..3e8340e 100644
--- a/qtwebengine/src/3rdparty/chromium/media/capture/video/linux/v4l2_capture_delegate.cc
+++ b/qtwebengine/src/3rdparty/chromium/media/capture/video/linux/v4l2_capture_delegate.cc
@@ -442,7 +442,7 @@ void V4L2CaptureDelegate::GetPhotoState(
   // AUTO, SHUTTER_PRIORITY or APERTURE_PRIORITY. Drivers should interpret the
   // values as 0.001 EV units, where the value 1000 stands for +1 EV.
   photo_capabilities->exposure_compensation =
-      RetrieveUserControlRange(V4L2_CID_AUTO_EXPOSURE_BIAS);
+      RetrieveUserControlRange(0x9a0913);
 
   // Determines the exposure time of the camera sensor. Drivers interpret values
   // as 100 µs units, same as specs.
@@ -589,7 +589,7 @@ void V4L2CaptureDelegate::SetPhotoOptions(
     // control is set to AUTO, SHUTTER_PRIORITY or APERTURE_PRIORITY.
     if (result >= 0 && auto_exposure_current.value != V4L2_EXPOSURE_MANUAL) {
       v4l2_control set_exposure = {};
-      set_exposure.id = V4L2_CID_AUTO_EXPOSURE_BIAS;
+      set_exposure.id = 0x9a0913;
       set_exposure.value = settings->exposure_compensation;
       DoIoctl(VIDIOC_S_CTRL, &set_exposure);
     }
diff --git a/qtwebengine/src/3rdparty/chromium/net/cookies/cookie_inclusion_status.h b/qtwebengine/src/3rdparty/chromium/net/cookies/cookie_inclusion_status.h
index 9e506b5..3758b29 100644
--- a/qtwebengine/src/3rdparty/chromium/net/cookies/cookie_inclusion_status.h
+++ b/qtwebengine/src/3rdparty/chromium/net/cookies/cookie_inclusion_status.h
@@ -4,6 +4,7 @@
 
 #ifndef NET_COOKIES_COOKIE_INCLUSION_STATUS_H_
 #define NET_COOKIES_COOKIE_INCLUSION_STATUS_H_
+#include <cstdint>
 
 #include <string>
 #include <vector>
diff --git a/qtwebengine/src/3rdparty/chromium/third_party/abseil-cpp/absl/strings/internal/str_format/extension.h b/qtwebengine/src/3rdparty/chromium/third_party/abseil-cpp/absl/strings/internal/str_format/extension.h
index a9b9e13..24e84f4 100644
--- a/qtwebengine/src/3rdparty/chromium/third_party/abseil-cpp/absl/strings/internal/str_format/extension.h
+++ b/qtwebengine/src/3rdparty/chromium/third_party/abseil-cpp/absl/strings/internal/str_format/extension.h
@@ -15,6 +15,7 @@
 //
 #ifndef ABSL_STRINGS_INTERNAL_STR_FORMAT_EXTENSION_H_
 #define ABSL_STRINGS_INTERNAL_STR_FORMAT_EXTENSION_H_
+#include <cstdint>
 
 #include <limits.h>
 
diff --git a/qtwebengine/src/3rdparty/chromium/third_party/angle/include/GLSLANG/ShaderVars.h b/qtwebengine/src/3rdparty/chromium/third_party/angle/include/GLSLANG/ShaderVars.h
index 9911546..6e75887 100644
--- a/qtwebengine/src/3rdparty/chromium/third_party/angle/include/GLSLANG/ShaderVars.h
+++ b/qtwebengine/src/3rdparty/chromium/third_party/angle/include/GLSLANG/ShaderVars.h
@@ -9,6 +9,7 @@
 
 #ifndef GLSLANG_SHADERVARS_H_
 #define GLSLANG_SHADERVARS_H_
+#include <cstdint>
 
 #include <algorithm>
 #include <array>
diff --git a/qtwebengine/src/3rdparty/chromium/third_party/angle/src/common/angleutils.h b/qtwebengine/src/3rdparty/chromium/third_party/angle/src/common/angleutils.h
index f669d7d..b14fec5 100644
--- a/qtwebengine/src/3rdparty/chromium/third_party/angle/src/common/angleutils.h
+++ b/qtwebengine/src/3rdparty/chromium/third_party/angle/src/common/angleutils.h
@@ -8,6 +8,7 @@
 
 #ifndef COMMON_ANGLEUTILS_H_
 #define COMMON_ANGLEUTILS_H_
+#include <cstdint>
 
 #include "common/platform.h"
 
diff --git a/qtwebengine/src/3rdparty/chromium/third_party/blink/renderer/platform/graphics/dark_mode_types.h b/qtwebengine/src/3rdparty/chromium/third_party/blink/renderer/platform/graphics/dark_mode_types.h
index 14c5548..f558ec3 100644
--- a/qtwebengine/src/3rdparty/chromium/third_party/blink/renderer/platform/graphics/dark_mode_types.h
+++ b/qtwebengine/src/3rdparty/chromium/third_party/blink/renderer/platform/graphics/dark_mode_types.h
@@ -4,6 +4,7 @@
 
 #ifndef THIRD_PARTY_BLINK_RENDERER_PLATFORM_GRAPHICS_DARK_MODE_TYPES_H_
 #define THIRD_PARTY_BLINK_RENDERER_PLATFORM_GRAPHICS_DARK_MODE_TYPES_H_
+#include <cstdint>
 
 namespace blink {
 
diff --git a/qtwebengine/src/3rdparty/chromium/third_party/breakpad/breakpad/src/client/linux/handler/minidump_descriptor.h b/qtwebengine/src/3rdparty/chromium/third_party/breakpad/breakpad/src/client/linux/handler/minidump_descriptor.h
index c7e4f2b..c3cddf8 100644
--- a/qtwebengine/src/3rdparty/chromium/third_party/breakpad/breakpad/src/client/linux/handler/minidump_descriptor.h
+++ b/qtwebengine/src/3rdparty/chromium/third_party/breakpad/breakpad/src/client/linux/handler/minidump_descriptor.h
@@ -29,6 +29,7 @@
 
 #ifndef CLIENT_LINUX_HANDLER_MINIDUMP_DESCRIPTOR_H_
 #define CLIENT_LINUX_HANDLER_MINIDUMP_DESCRIPTOR_H_
+#include <cstdint>
 
 #include <assert.h>
 #include <sys/types.h>
diff --git a/qtwebengine/src/3rdparty/chromium/third_party/crashpad/crashpad/compat/linux/sys/mman_memfd_create.cc b/qtwebengine/src/3rdparty/chromium/third_party/crashpad/crashpad/compat/linux/sys/mman_memfd_create.cc
index e0ee5a4..43f9c82 100644
--- a/qtwebengine/src/3rdparty/chromium/third_party/crashpad/crashpad/compat/linux/sys/mman_memfd_create.cc
+++ b/qtwebengine/src/3rdparty/chromium/third_party/crashpad/crashpad/compat/linux/sys/mman_memfd_create.cc
@@ -28,7 +28,7 @@ int memfd_create(const char* name, unsigned int flags) {
   static const crashpad::NoCfiIcall<decltype(memfd_create)*> next_memfd_create(
       dlsym(RTLD_NEXT, "memfd_create"));
   return next_memfd_create ? next_memfd_create(name, flags)
-                           : syscall(SYS_memfd_create, name, flags);
+                           : syscall(319, name, flags);
 }
 
 }  // extern "C"
diff --git a/qtwebengine/src/3rdparty/chromium/third_party/ffmpeg/libavcodec/x86/mathops.h b/qtwebengine/src/3rdparty/chromium/third_party/ffmpeg/libavcodec/x86/mathops.h
index 6298f5e..ca7e2df 100644
--- a/qtwebengine/src/3rdparty/chromium/third_party/ffmpeg/libavcodec/x86/mathops.h
+++ b/qtwebengine/src/3rdparty/chromium/third_party/ffmpeg/libavcodec/x86/mathops.h
@@ -35,12 +35,20 @@
 static av_always_inline av_const int MULL(int a, int b, unsigned shift)
 {
     int rt, dummy;
+    if (__builtin_constant_p(shift))
     __asm__ (
         "imull %3               \n\t"
         "shrdl %4, %%edx, %%eax \n\t"
         :"=a"(rt), "=d"(dummy)
-        :"a"(a), "rm"(b), "ci"((uint8_t)shift)
+        :"a"(a), "rm"(b), "i"(shift & 0x1F)
     );
+    else
+        __asm__ (
+            "imull %3               \n\t"
+            "shrdl %4, %%edx, %%eax \n\t"
+            :"=a"(rt), "=d"(dummy)
+            :"a"(a), "rm"(b), "c"((uint8_t)shift)
+        );
     return rt;
 }
 
@@ -113,19 +121,31 @@ __asm__ volatile(\
 // avoid +32 for shift optimization (gcc should do that ...)
 #define NEG_SSR32 NEG_SSR32
 static inline  int32_t NEG_SSR32( int32_t a, int8_t s){
+    if (__builtin_constant_p(s))
     __asm__ ("sarl %1, %0\n\t"
          : "+r" (a)
-         : "ic" ((uint8_t)(-s))
+         : "i" (-s & 0x1F)
     );
+    else
+        __asm__ ("sarl %1, %0\n\t"
+               : "+r" (a)
+               : "c" ((uint8_t)(-s))
+        );
     return a;
 }
 
 #define NEG_USR32 NEG_USR32
 static inline uint32_t NEG_USR32(uint32_t a, int8_t s){
+    if (__builtin_constant_p(s))
     __asm__ ("shrl %1, %0\n\t"
          : "+r" (a)
-         : "ic" ((uint8_t)(-s))
+         : "i" (-s & 0x1F)
     );
+    else
+        __asm__ ("shrl %1, %0\n\t"
+               : "+r" (a)
+               : "c" ((uint8_t)(-s))
+        );
     return a;
 }
 
diff --git a/qtwebengine/src/3rdparty/chromium/third_party/perfetto/include/perfetto/ext/base/uuid.h b/qtwebengine/src/3rdparty/chromium/third_party/perfetto/include/perfetto/ext/base/uuid.h
index 1b4c538..2befd3e 100644
--- a/qtwebengine/src/3rdparty/chromium/third_party/perfetto/include/perfetto/ext/base/uuid.h
+++ b/qtwebengine/src/3rdparty/chromium/third_party/perfetto/include/perfetto/ext/base/uuid.h
@@ -16,6 +16,7 @@
 
 #ifndef INCLUDE_PERFETTO_EXT_BASE_UUID_H_
 #define INCLUDE_PERFETTO_EXT_BASE_UUID_H_
+#include <cstdint>
 
 #include <array>
 #include <string>
diff --git a/qtwebengine/src/3rdparty/chromium/third_party/skia/src/utils/SkParseColor.cpp b/qtwebengine/src/3rdparty/chromium/third_party/skia/src/utils/SkParseColor.cpp
index 7260365..cd07eb4 100644
--- a/qtwebengine/src/3rdparty/chromium/third_party/skia/src/utils/SkParseColor.cpp
+++ b/qtwebengine/src/3rdparty/chromium/third_party/skia/src/utils/SkParseColor.cpp
@@ -7,6 +7,7 @@
 
 
 #include "include/utils/SkParse.h"
+#include <vector>
 
 static constexpr const char* gColorNames[] = {
     "aliceblue",
diff --git a/qtwebengine/src/3rdparty/chromium/third_party/webrtc/call/rtp_demuxer.h b/qtwebengine/src/3rdparty/chromium/third_party/webrtc/call/rtp_demuxer.h
index 3aa7e9d..257f6c6 100644
--- a/qtwebengine/src/3rdparty/chromium/third_party/webrtc/call/rtp_demuxer.h
+++ b/qtwebengine/src/3rdparty/chromium/third_party/webrtc/call/rtp_demuxer.h
@@ -10,6 +10,7 @@
 
 #ifndef CALL_RTP_DEMUXER_H_
 #define CALL_RTP_DEMUXER_H_
+#include <cstdint>
 
 #include <map>
 #include <set>
diff --git a/qtwebengine/src/3rdparty/chromium/third_party/webrtc/rtc_base/third_party/base64/base64.h b/qtwebengine/src/3rdparty/chromium/third_party/webrtc/rtc_base/third_party/base64/base64.h
index 7a936f2..835bf0a 100644
--- a/qtwebengine/src/3rdparty/chromium/third_party/webrtc/rtc_base/third_party/base64/base64.h
+++ b/qtwebengine/src/3rdparty/chromium/third_party/webrtc/rtc_base/third_party/base64/base64.h
@@ -11,6 +11,7 @@
 
 #ifndef RTC_BASE_THIRD_PARTY_BASE64_BASE64_H_
 #define RTC_BASE_THIRD_PARTY_BASE64_BASE64_H_
+#include <cstdint>
 
 #include <string>
 #include <vector>
diff --git a/qtwebengine/src/3rdparty/chromium/third_party/xcbproto/src/src/present.xml b/qtwebengine/src/3rdparty/chromium/third_party/xcbproto/src/src/present.xml
index fb06e73..235faae 100644
--- a/qtwebengine/src/3rdparty/chromium/third_party/xcbproto/src/src/present.xml
+++ b/qtwebengine/src/3rdparty/chromium/third_party/xcbproto/src/src/present.xml
@@ -62,7 +62,7 @@ OF THIS SOFTWARE.
   </enum>
 
   <enum name="CompleteKind">
-    <item name="Pixmap"><value>0</value></item>
+    <item name="Pix"><value>0</value></item>
     <item name="NotifyMSC"><value>1</value></item>
   </enum>
 
@@ -89,7 +89,7 @@ OF THIS SOFTWARE.
     </reply>
   </request>
 
-  <request name="Pixmap" opcode="1">
+  <request name="Pix" opcode="1">
     <required_start_align align="8" />
     <field type="WINDOW" name="window" />
     <field type="PIXMAP" name="pixmap" />
diff --git a/qtwebengine/src/3rdparty/chromium/v8/src/base/logging.h b/qtwebengine/src/3rdparty/chromium/v8/src/base/logging.h
index fe39f98..773017e 100644
--- a/qtwebengine/src/3rdparty/chromium/v8/src/base/logging.h
+++ b/qtwebengine/src/3rdparty/chromium/v8/src/base/logging.h
@@ -4,6 +4,7 @@
 
 #ifndef V8_BASE_LOGGING_H_
 #define V8_BASE_LOGGING_H_
+#include <cstdint>
 
 #include <cstring>
 #include <sstream>
diff --git a/qtwebengine/src/3rdparty/chromium/v8/src/inspector/v8-string-conversions.h b/qtwebengine/src/3rdparty/chromium/v8/src/inspector/v8-string-conversions.h
index c1d69c1..14b0a54 100644
--- a/qtwebengine/src/3rdparty/chromium/v8/src/inspector/v8-string-conversions.h
+++ b/qtwebengine/src/3rdparty/chromium/v8/src/inspector/v8-string-conversions.h
@@ -4,6 +4,7 @@
 
 #ifndef V8_INSPECTOR_V8_STRING_CONVERSIONS_H_
 #define V8_INSPECTOR_V8_STRING_CONVERSIONS_H_
+#include <cstdint>
 
 #include <string>
 
diff --git a/qtwebengine/src/buildtools/configure.json b/qtwebengine/src/buildtools/configure.json
index 88d1790..dfc9975 100644
--- a/qtwebengine/src/buildtools/configure.json
+++ b/qtwebengine/src/buildtools/configure.json
@@ -270,7 +270,7 @@
             "test": {
                 "include": "features.h",
                 "tail": [
-                    "#if __GLIBC__ < 2 || __GLIBC_MINOR__ < 17",
+                    "#if __GLIBC__ < 2 || __GLIBC_MINOR__ < 15",
                     "#error glibc versions below 2.17 are not supported",
                     "#endif"
                 ]
diff --git a/qtwebengine/src/buildtools/gn.pro b/qtwebengine/src/buildtools/gn.pro
index f94694d..5f2b594 100644
--- a/qtwebengine/src/buildtools/gn.pro
+++ b/qtwebengine/src/buildtools/gn.pro
@@ -20,7 +20,7 @@ build_pass|!debug_and_release {
 
             gn_gen_args = --no-last-commit-position --out-path $$out_path \
                           --cc \"$$which($$QMAKE_CC)\" --cxx \"$$which($$QMAKE_CXX)\" \
-                          --ld \"$$which($$QMAKE_LINK)\"
+                          --ld \"$$which($$QMAKE_LINK) -lrt\"
             !isEmpty(QMAKE_AR): gn_gen_args += --ar \"$$which($$first(QMAKE_AR))\"
 
             msvc:!clang_cl: gn_gen_args += --use-lto

diff --git a/qtwebengine/src/3rdparty/chromium/third_party/crashpad/crashpad/util/file/file_io_posix.cc b/qtwebengine/src/3rdparty/chromium/third_party/crashpad/crashpad/util/file/file_io_posix.cc
index 2baa811..6676953 100644
--- a/qtwebengine/src/3rdparty/chromium/third_party/crashpad/crashpad/util/file/file_io_posix.cc
+++ b/qtwebengine/src/3rdparty/chromium/third_party/crashpad/crashpad/util/file/file_io_posix.cc
@@ -166,16 +166,16 @@ FileHandle LoggingOpenMemoryFileForReadAndWrite(const base::FilePath& name) {
   const char* tmp = getenv("TMPDIR");
   tmp = tmp ? tmp : "/tmp";
 
-  result = HANDLE_EINTR(open(tmp, O_RDWR | O_EXCL | O_TMPFILE, 0600));
+  result = HANDLE_EINTR(open(tmp, O_RDWR | O_EXCL | 0x020200000, 0600));
   if (result >= 0 ||
       // These are the expected possible error codes indicating that O_TMPFILE
       // doesn't have kernel or filesystem support. O_TMPFILE was added in Linux
       // 3.11. Experimentation confirms that at least Linux 2.6.29 and Linux
       // 3.10 set errno to EISDIR. EOPNOTSUPP is returned when the filesystem
       // doesn't support O_TMPFILE. The man pages also mention ENOENT as an
       // error code to check, but the language implies it would only occur when
       // |tmp| is also an invalid directory. EINVAL is mentioned as a possible
       // error code for any invalid values in flags, but O_TMPFILE isn't
       // mentioned explicitly in this context and hasn't been observed in
       // practice.
       (errno != EISDIR && errno != EOPNOTSUPP)) {
@@ -166,16 +166,16 @@ FileHandle LoggingOpenMemoryFileForReadAndWrite(const base::FilePath& name) {
   if (result >= 0 ||
-      // These are the expected possible error codes indicating that O_TMPFILE
-      // doesn't have kernel or filesystem support. O_TMPFILE was added in Linux
+      // These are the expected possible error codes indicating that 0x020200000
+      // doesn't have kernel or filesystem support. 0x020200000 was added in Linux
       // 3.11. Experimentation confirms that at least Linux 2.6.29 and Linux
       // 3.10 set errno to EISDIR. EOPNOTSUPP is returned when the filesystem
@@ -166,16 +166,16 @@ FileHandle LoggingOpenMemoryFileForReadAndWrite(const base::FilePath& name) {
       // 3.11. Experimentation confirms that at least Linux 2.6.29 and Linux
       // 3.10 set errno to EISDIR. EOPNOTSUPP is returned when the filesystem
-      // doesn't support O_TMPFILE. The man pages also mention ENOENT as an
+      // doesn't support 0x020200000. The man pages also mention ENOENT as an
       // error code to check, but the language implies it would only occur when
       // |tmp| is also an invalid directory. EINVAL is mentioned as a possible
@@ -166,16 +166,16 @@ FileHandle LoggingOpenMemoryFileForReadAndWrite(const base::FilePath& name) {
       // error code to check, but the language implies it would only occur when
       // |tmp| is also an invalid directory. EINVAL is mentioned as a possible
-      // error code for any invalid values in flags, but O_TMPFILE isn't
+      // error code for any invalid values in flags, but 0x020200000 isn't
       // mentioned explicitly in this context and hasn't been observed in
       // practice.